/*!
 * (C) Copyright IBM Corp. 2005, 2005
 *
 * \file loader.h
 * \brief Include file for kboot loader module.
 *
 * $Id: loader.h,v 1.7 2006/02/09 16:17:57 loehr Exp $
 *
 * Author(s): Ralph Wuerthner (rwuerthn@de.ibm.com)
 */


#ifndef _LOADER_H_
#define _LOADER_H_

#include "config.h"

#define KBOOT_MAX_KERNEL_CMDLINE 4096
//!< maximum kernel command line length
#define KBOOT_KEXEC_CMD "/sbin/kexec"
//!< path to kexec tool
#define KBOOT_REBOOT_CMD "/sbin/reboot"
//!< path to reboot command
#define KBOOT_HALT_CMD "/sbin/halt"
//!< path to halt command
#define KBOOT_FILENAME_KERNEL    "/tmp/kernel.img"
//!< filename for local kernel image
#define KBOOT_FILENAME_INITRD    "/tmp/initrd.img"
//!< filename for local initrd image
#define KBOOT_FILENAME_PARMFILE  "/tmp/parmfile.txt"
//!< filename for local parmfile copy
#define KBOOT_FILENAME_INSFILE  "/tmp/file.ins"
//!< filename for local insfile copy


char *loader(struct cfg_bentry *boot);
char *prefix_root(const char *root, const char *uri);
char *compose_commandline(char **final_cmdline, const char *parmfile,
			  const char *cmdline);
char *kexec(const char *kernel, const char *initrd, const char *cmdline);
char *action_insfile_boot(struct cfg_bentry *boot);
char *action_bootmap_boot(struct cfg_bentry *boot);

#endif /* #ifndef _LOADER_H_ */
